[PATCH] D27374: [PM] Rename lookupPass to lookUpPass.
Justin Lebar via Phabricator via llvm-commits
llvm-commits at lists.llvm.org
Sat Dec 3 11:59:45 PST 2016
This revision was automatically updated to reflect the committed changes.
Closed by commit rL288598: [PM] Rename lookupPass to lookUpPass. (authored by jlebar).
Changed prior to commit:
https://reviews.llvm.org/D27374?vs=80149&id=80188#toc
Repository:
rL LLVM
https://reviews.llvm.org/D27374
Files:
llvm/trunk/include/llvm/IR/PassManager.h
Index: llvm/trunk/include/llvm/IR/PassManager.h
===================================================================
--- llvm/trunk/include/llvm/IR/PassManager.h
+++ llvm/trunk/include/llvm/IR/PassManager.h
@@ -638,16 +638,16 @@
}
private:
- /// \brief Lookup a registered analysis pass.
- PassConceptT &lookupPass(AnalysisKey *ID) {
+ /// \brief Look up a registered analysis pass.
+ PassConceptT &lookUpPass(AnalysisKey *ID) {
typename AnalysisPassMapT::iterator PI = AnalysisPasses.find(ID);
assert(PI != AnalysisPasses.end() &&
"Analysis passes must be registered prior to being queried!");
return *PI->second;
}
- /// \brief Lookup a registered analysis pass.
- const PassConceptT &lookupPass(AnalysisKey *ID) const {
+ /// \brief Look up a registered analysis pass.
+ const PassConceptT &lookUpPass(AnalysisKey *ID) const {
typename AnalysisPassMapT::const_iterator PI = AnalysisPasses.find(ID);
assert(PI != AnalysisPasses.end() &&
"Analysis passes must be registered prior to being queried!");
@@ -665,7 +665,7 @@
// If we don't have a cached result for this function, look up the pass and
// run it to produce a result, which we then add to the cache.
if (Inserted) {
- auto &P = this->lookupPass(ID);
+ auto &P = this->lookUpPass(ID);
if (DebugLogging)
dbgs() << "Running analysis: " << P.name() << "\n";
AnalysisResultListT &ResultList = AnalysisResultLists[&IR];
@@ -697,7 +697,7 @@
return;
if (DebugLogging)
- dbgs() << "Invalidating analysis: " << this->lookupPass(ID).name()
+ dbgs() << "Invalidating analysis: " << this->lookUpPass(ID).name()
<< "\n";
AnalysisResultLists[&IR].erase(RI->second);
AnalysisResults.erase(RI);
-------------- next part --------------
A non-text attachment was scrubbed...
Name: D27374.80188.patch
Type: text/x-patch
Size: 1802 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20161203/6cfd864f/attachment.bin>
More information about the llvm-commits
mailing list